pub static ANIMALS: &[&str] = &[
    "rooks",
    "weasels",
    "peafowl",
    "reindeers",
    "ocelots",
    "dingos",
    "spiders",
    "hawks",
    "flies",
    "rhinoceross",
    "hedgehogs",
    "prairie_dogs",
    "armadillos",
    "rats",
    "goats",
    "yaks",
    "gregs",
    "antelopes",
    "parrots",
    "gazelles",
    "wildcats",
    "ewes",
    "oxs",
    "horses",
    "bisons",
    "squirrels",
    "crocodiles",
    "platypuss",
    "cougars",
    "minks",
    "trouts",
    "wolves",
    "ground_hogs",
    "mussles",
    "guinea_pigs",
    "snails",
    "salmons",
    "porpoises",
    "gnus",
    "cockles",
    "elephants",
    "lions",
    "mouses",
    "finchs",
    "iguanas",
    "chipmunks",
    "capybaras",
    "walruses",
    "lemurs",
    "panthers",
    "hamsters",
    "crabs",
    "bats",
    "silver_foxs",
    "shrews",
    "reptiles",
    "koalas",
    "crows",
    "impalas",
    "raccoons",
    "deers",
    "pheasants",
    "woodchucks",
    "donkeys",
    "dromedaries",
    "coyotes",
    "dogs",
    "elks",
    "snakes",
    "pigs",
    "mynah_birds",
    "monkeys",
    "baboons",
    "kangaroos",
    "ants",
    "mongooses",
    "parakeets",
    "canaries",
    "aardvarks",
    "apes",
    "pumas",
    "ducks",
    "jaguars",
    "foxes",
    "beavers",
    "leopards",
    "oysters",
    "kingfishers",
    "lambs",
    "boars",
    "chickens",
    "otters",
    "lizards",
    "turtles",
    "cats",
    "newts",
    "jackals",
    "lynxes",
    "frogs",
    "whales",
    "bulls",
    "chimpanzees",
    "mustangs",
    "hyenas",
    "mules",
    "butterflies",
    "robins",
    "alpacas",
    "hares",
    "rabbits",
    "rams",
    "owls",
    "opossums",
    "warthogs",
    "chinchillas",
    "toads",
    "gila_monsters",
    "sheeps",
    "lobsters",
    "ferrets",
    "oryxs",
    "polar_bears",
    "herons",
    "badgers",
    "seals",
    "cattle",
    "pigeons",
    "hogs",
];
